@@ -74,22 +74,21 @@ static const int GZIP_WINDOW_BITS = -15; // no zlib header
 static const int Z_DEFAULT_MEM_LEVEL = 8;
 
 
-inline
-void
+static R_INLINE void
 packInt16(uint8_t* buffer, uint16_t value)
 {
     buffer[0] = value;
     buffer[1] = value >> 8;
 }
 
-inline
+static R_INLINE
 int
 unpackInt16(const uint8_t* buffer)
 {
     return (buffer[0] | (buffer[1] << 8));
 }
 
-inline
+static R_INLINE
 void
 packInt32(uint8_t* buffer, uint32_t value)
 {
@@ -99,7 +98,7 @@ packInt32(uint8_t* buffer, uint32_t value)
     buffer[3] = value >> 24;
 }
 
-static inline
+static R_INLINE
 int
 bgzf_min(int x, int y)
 {
